<a href="https://travis-ci.org/flav-io/flavio">![Build Status](https://travis-ci.org/flav-io/flavio.svg?branch=master)</a> [![Coverage Status](https://coveralls.io/repos/github/flav-io/flavio/badge.svg)](https://coveralls.io/github/flav-io/flavio) [![DOI](https://zenodo.org/badge/22356/flav-io/flavio.svg)](https://zenodo.org/badge/latestdoi/22356/flav-io/flavio)

# flavio – flavour phenomenology in the Standard model and beyond

flavio is a Python package to compute observables in flavour physics both in
the Standard Model and in the presence of new physics encoded in Wilson
coefficients of dimension-6 operators.

## Project status

The project is currently in beta phase, so should be used with reasonable caution.

## Contributors

- David M. Straub (<david.straub@tum.de>)

## Project web site

Further information and the package documentation can be found at:

http://flav-io.github.io

This web site is built with Jekyll and hosted on Github pages. You can check
out its source (or submit pull requests) at https://github.com/flav-io/flav-io.github.io.

## Installation

See http://flav-io.github.io/docs/installation.html for instructions.

## Bugs and feature request

Please submit bugs and feature request using
[Github's issue system](https://github.com/flav-io/flavio/issues) rather than
by E-mail. Thanks!

## License

flavio is released under the MIT license.

## Citation

If you use flavio in a project, please cite:

[![DOI](https://zenodo.org/badge/22356/flav-io/flavio.svg)](https://zenodo.org/badge/latestdoi/22356/flav-io/flavio)
